@@ -17,7 +17,7 @@ def isWinAtTimeIntervals(pnl: trdb2py.trading2_pb2.PNLAssetData, tsStart: int, t
 
     for v in pnl.values:
         if v.ts >= tsStart and v.ts < tsEnd:
-            if hasStart:
+            if not hasStart:
                 hasStart = True
                 pvStart = v.perValue
 
@@ -68,9 +68,9 @@ def calcPNLWinRateInYear(pnl: trdb2py.trading2_pb2.PNLAssetData, year: int) -> d
             pnl, dtStart.timestamp(), dtEnd.timestamp())
 
         if iswin:
-            return 1.0
-
-        return 0.0
+            ret['winrate'] = 1.0
+        else:
+            ret['winrate'] = 0.0
 
     return ret
 
